COMMAND builtin_command_data[] = {
0, 0, 0,
"\t", CF_nobrace, 0,
"\n", CF_nobrace, 0,
"\x20", CF_nobrace, 0,
"!", CF_nobrace, 0,
"\"", CF_brace | CF_accent, BRACE_accent,
"&", CF_nobrace, 0,
"'", CF_brace | CF_accent, BRACE_accent,
"*", CF_nobrace, 0,
",", CF_brace | CF_accent, BRACE_accent,
"-", CF_nobrace, 0,
".", CF_nobrace, 0,
"/", CF_nobrace, 0,
":", CF_nobrace, 0,
"=", CF_brace | CF_accent, BRACE_accent,
"?", CF_nobrace, 0,
"@", CF_nobrace, 0,
"AA", CF_brace, 0,
"AE", CF_brace, 0,
"DH", CF_brace, 0,
"H", CF_brace | CF_accent, BRACE_accent,
"L", CF_brace, 0,
"LaTeX", CF_brace, 0,
"O", CF_brace, 0,
"OE", CF_brace, 0,
"TH", CF_brace, 0,
"TeX", CF_brace, 0,
"U", CF_brace, 1,
"\\", CF_nobrace, 0,
"^", CF_brace | CF_accent, BRACE_accent,
"`", CF_brace | CF_accent, BRACE_accent,
"aa", CF_brace, 0,
"abbr", CF_brace, 2,
"acronym", CF_brace, 2,
"ae", CF_brace, 0,
"afivepaper", CF_line, LINE_skipline,
"afourlatex", CF_line, LINE_skipline,
"afourpaper", CF_line, LINE_skipline,
"afourwide", CF_line, LINE_skipline,
"alias", CF_line, 2,
"allowcodebreaks", CF_line | CF_global, 1,
"ampchar", CF_brace, 0,
"anchor", CF_brace, 1,
"appendix", CF_root | CF_line | CF_sectioning, LINE_line,
"appendixsec", CF_root | CF_line | CF_sectioning, LINE_line,
"appendixsection", CF_root | CF_line | CF_sectioning, LINE_line,
"appendixsubsec", CF_root | CF_line | CF_sectioning, LINE_line,
"appendixsubsubsec", CF_root | CF_line | CF_sectioning, LINE_line,
"arrow", CF_brace, 0,
"asis", CF_brace, BRACE_style,
"atchar", CF_brace, 0,
"author", CF_line | CF_global, LINE_line,
"b", CF_brace, BRACE_style,
"backslashchar", CF_brace, 0,
"bsixpaper", CF_line, LINE_skipline,
"bullet", CF_brace, 0,
"bye", CF_line, LINE_skipline,
"c", CF_line, LINE_lineraw,
"caption", CF_brace, BRACE_context,
"cartouche", CF_block, 0,
"center", CF_line, LINE_line,
"centerchap", CF_root | CF_line | CF_sectioning | CF_deprecated, LINE_line,
"chapheading", CF_line | CF_sectioning, LINE_line,
"chapter", CF_root | CF_line | CF_sectioning, LINE_line,
"cite", CF_brace, BRACE_style,
"clear", CF_line, LINE_special,
"click", CF_brace, 0,
"clicksequence", CF_brace, BRACE_style,
"clickstyle", CF_line | CF_global, LINE_special,
"code", CF_brace | CF_code_style, BRACE_style,
"codequotebacktick", CF_line | CF_global, 1,
"codequoteundirected", CF_line | CF_global, 1,
"columnfractions", CF_line, 1,
"comma", CF_brace, 0,
"command", CF_brace | CF_code_style, BRACE_style,
"comment", CF_line, LINE_lineraw,
"contents", CF_line | CF_global, LINE_skipline,
"copying", CF_block | CF_global_unique, BLOCK_region,
"copyright", CF_brace, 0,
"defcodeindex", CF_line, 1,
"defcv", CF_block | CF_def, 0,
"defcvx", CF_line | CF_def, LINE_line,
"deffn", CF_block | CF_def, 0,
"deffnx", CF_line | CF_def, LINE_line,
"defindex", CF_line, 1,
"definfoenclose", CF_line | CF_deprecated, 3,
"defivar", CF_block | CF_def | CF_def_alias, 0,
"defivarx", CF_line | CF_def | CF_def_alias, LINE_line,
"defmac", CF_block | CF_def | CF_def_alias, 0,
"defmacx", CF_line | CF_def | CF_def_alias, LINE_line,
"defmethod", CF_block | CF_def | CF_def_alias, 0,
"defmethodx", CF_line | CF_def | CF_def_alias, LINE_line,
"defop", CF_block | CF_def, 0,
"defopt", CF_block | CF_def | CF_def_alias, 0,
"defoptx", CF_line | CF_def | CF_def_alias, LINE_line,
"defopx", CF_line | CF_def, LINE_line,
"defspec", CF_block | CF_def | CF_def_alias, 0,
"defspecx", CF_line | CF_def | CF_def_alias, LINE_line,
"deftp", CF_block | CF_def, 0,
"deftpx", CF_line | CF_def, LINE_line,
"deftypecv", CF_block | CF_def, 0,
"deftypecvx", CF_line | CF_def, LINE_line,
"deftypefn", CF_block | CF_def, 0,
"deftypefnnewline", CF_line | CF_global, 1,
"deftypefnx", CF_line | CF_def, LINE_line,
"deftypefun", CF_block | CF_def | CF_def_alias, 0,
"deftypefunx", CF_line | CF_def | CF_def_alias, LINE_line,
"deftypeivar", CF_block | CF_def | CF_def_alias, 0,
"deftypeivarx", CF_line | CF_def | CF_def_alias, LINE_line,
"deftypemethod", CF_block | CF_def | CF_def_alias, 0,
"deftypemethodx", CF_line | CF_def | CF_def_alias, LINE_line,
"deftypeop", CF_block | CF_def, 0,
"deftypeopx", CF_line | CF_def, LINE_line,
"deftypevar", CF_block | CF_def | CF_def_alias, 0,
"deftypevarx", CF_line | CF_def | CF_def_alias, LINE_line,
"deftypevr", CF_block | CF_def, 0,
"deftypevrx", CF_line | CF_def, LINE_line,
"defun", CF_block | CF_def | CF_def_alias, 0,
"defunx", CF_line | CF_def | CF_def_alias, LINE_line,
"defvar", CF_block | CF_def | CF_def_alias, 0,
"defvarx", CF_line | CF_def | CF_def_alias, LINE_line,
"defvr", CF_block | CF_def, 0,
"defvrx", CF_line | CF_def, LINE_line,
"detailmenu", CF_block | CF_menu | CF_global, 0,
"dfn", CF_brace, BRACE_style,
"dh", CF_brace, 0,
"dircategory", CF_line, LINE_line,
"direntry", CF_block | CF_menu, 0,
"display", CF_block | CF_preformatted, 0,
"displaymath", CF_block, 0,
"dmn", CF_brace, 1,
"docbook", CF_block | CF_format_raw, 0,
"documentdescription", CF_block | CF_global_unique, BLOCK_region,
"documentencoding", CF_line | CF_global, LINE_text,
"documentlanguage", CF_line | CF_global, LINE_text,
"dotaccent", CF_brace | CF_accent, BRACE_accent,
"dotless", CF_brace | CF_accent, BRACE_accent,
"dots", CF_brace, 0,
"email", CF_brace, 2,
"emph", CF_brace, BRACE_style,
"end", CF_line, LINE_text,
"enddots", CF_brace, 0,
"enumerate", CF_block | CF_blockitem, 1,
"env", CF_brace | CF_code_style, BRACE_style,
"equiv", CF_brace, 0,
"error", CF_brace, 0,
"errormsg", CF_brace, 1,
"euro", CF_brace, 0,
"evenfooting", CF_line | CF_global_unique, LINE_lineraw,
"evenfootingmarks", CF_line | CF_global_unique, 1,
"evenheading", CF_line | CF_global_unique, LINE_lineraw,
"evenheadingmarks", CF_line | CF_global_unique, 1,
"everyfooting", CF_line | CF_global_unique, LINE_lineraw,
"everyfootingmarks", CF_line | CF_global_unique, 1,
"everyheading", CF_line | CF_global_unique, LINE_lineraw,
"everyheadingmarks", CF_line | CF_global_unique, 1,
"example", CF_block | CF_preformatted | CF_preformatted_code, BLOCK_variadic,
"exampleindent", CF_line | CF_global, 1,
"exclamdown", CF_brace, 0,
"exdent", CF_line, LINE_line,
"expansion", CF_brace, 0,
"file", CF_brace | CF_code_style, BRACE_style,
"finalout", CF_line, LINE_skipline,
"firstparagraphindent", CF_line | CF_global, 1,
"float", CF_block, 2,
"flushleft", CF_block, 0,
"flushright", CF_block, 0,
"fonttextsize", CF_line | CF_global_unique, 1,
"footnote", CF_brace | CF_global, BRACE_context,
"footnotestyle", CF_line | CF_global_unique, 1,
"format", CF_block | CF_preformatted, 0,
"frenchspacing", CF_line | CF_global, 1,
"ftable", CF_block | CF_blockitem, 1,
"geq", CF_brace, 0,
"group", CF_block, 0,
"guillemetleft", CF_brace, 0,
"guillemetright", CF_brace, 0,
"guillemotleft", CF_brace, 0,
"guillemotright", CF_brace, 0,
"guilsinglleft", CF_brace, 0,
"guilsinglright", CF_brace, 0,
"hashchar", CF_brace, 0,
"heading", CF_line | CF_sectioning, LINE_line,
"headings", CF_line | CF_global, 1,
"headitem", CF_other, OTHER_skipspace,
"headitemfont", CF_brace, BRACE_style,
"html", CF_block | CF_format_raw, 0,
"hyphenation", CF_brace | CF_global, BRACE_other,
"i", CF_brace, BRACE_style,
"ifclear", CF_block, BLOCK_conditional,
"ifcommanddefined", CF_block, BLOCK_conditional,
"ifcommandnotdefined", CF_block, BLOCK_conditional,
"ifdocbook", CF_block, BLOCK_conditional,
"ifhtml", CF_block, BLOCK_conditional,
"ifinfo", CF_block, BLOCK_conditional,
"ifnotdocbook", CF_block, BLOCK_conditional,
"ifnothtml", CF_block, BLOCK_conditional,
"ifnotinfo", CF_block, BLOCK_conditional,
"ifnotplaintext", CF_block, BLOCK_conditional,
"ifnottex", CF_block, BLOCK_conditional,
"ifnotxml", CF_block, BLOCK_conditional,
"ifplaintext", CF_block, BLOCK_conditional,
"ifset", CF_block, BLOCK_conditional,
"iftex", CF_block, BLOCK_conditional,
"ifxml", CF_block, BLOCK_conditional,
"ignore", CF_block, BLOCK_raw,
"image", CF_brace, 5,
"include", CF_line, LINE_text,
"indent", CF_other, OTHER_skipspace,
"indentedblock", CF_block, 0,
"indicateurl", CF_brace | CF_code_style, 1,
"inforef", CF_brace | CF_ref | CF_deprecated, 3,
"inlinefmt", CF_brace | CF_inline, 2,
"inlinefmtifelse", CF_brace | CF_inline, 3,
"inlineifclear", CF_brace | CF_inline, 2,
"inlineifset", CF_brace | CF_inline, 2,
"inlineraw", CF_brace | CF_inline, 2,
"insertcopying", CF_line | CF_global, LINE_skipline,
"item", CF_other, OTHER_skipspace,
"item_LINE", CF_line, LINE_line,
"itemize", CF_block | CF_blockitem, 1,
"itemx", CF_line, LINE_line,
"kbd", CF_brace | CF_code_style, BRACE_style,
"kbdinputstyle", CF_line | CF_global, 1,
"key", CF_brace, BRACE_other,
"l", CF_brace, 0,
"lbracechar", CF_brace, 0,
"leq", CF_brace, 0,
"lisp", CF_block | CF_preformatted | CF_preformatted_code, 0,
"listoffloats", CF_line | CF_global, LINE_line,
"lowersections", CF_line, LINE_skipline,
"macro", CF_block, BLOCK_raw,
"majorheading", CF_line | CF_sectioning, LINE_line,
"math", CF_brace, BRACE_context,
"menu", CF_block | CF_menu, 0,
"minus", CF_brace, 0,
"multitable", CF_block | CF_blockitem, BLOCK_multitable,
"need", CF_line, 1,
"node", CF_root | CF_line, LINE_line,
"noindent", CF_other, OTHER_skipspace,
"novalidate", CF_line | CF_global_unique, LINE_skipline,
"o", CF_brace, 0,
"oddfooting", CF_line | CF_global_unique, LINE_lineraw,
"oddfootingmarks", CF_line | CF_global_unique, 1,
"oddheading", CF_line | CF_global_unique, LINE_lineraw,
"oddheadingmarks", CF_line | CF_global_unique, 1,
"oe", CF_brace, 0,
"ogonek", CF_brace | CF_accent, BRACE_accent,
"option", CF_brace | CF_code_style, BRACE_style,
"ordf", CF_brace, 0,
"ordm", CF_brace, 0,
"page", CF_line, LINE_skipline,
"pagesizes", CF_line | CF_global_unique, LINE_line,
"paragraphindent", CF_line | CF_global, 1,
"part", CF_root | CF_line | CF_sectioning | CF_global, LINE_line,
"point", CF_brace, 0,
"pounds", CF_brace, 0,
"print", CF_brace, 0,
"printindex", CF_line | CF_global, 1,
"pxref", CF_brace | CF_ref, 5,
"questiondown", CF_brace, 0,
"quotation", CF_block, 1,
"quotedblbase", CF_brace, 0,
"quotedblleft", CF_brace, 0,
"quotedblright", CF_brace, 0,
"quoteleft", CF_brace, 0,
"quoteright", CF_brace, 0,
"quotesinglbase", CF_brace, 0,
"r", CF_brace, BRACE_style,
"raggedright", CF_block, 0,
"raisesections", CF_line, LINE_skipline,
"rbracechar", CF_brace, 0,
"ref", CF_brace | CF_ref, 5,
"refill", CF_other | CF_deprecated, OTHER_noarg,
"registeredsymbol", CF_brace, 0,
"result", CF_brace, 0,
"ringaccent", CF_brace | CF_accent, BRACE_accent,
"rmacro", CF_block, BLOCK_raw,
"samp", CF_brace | CF_code_style, BRACE_style,
"sansserif", CF_brace, BRACE_style,
"sc", CF_brace, BRACE_style,
"section", CF_root | CF_line | CF_sectioning, LINE_line,
"seealso", CF_brace, 1,
"seeentry", CF_brace, 1,
"set", CF_line, LINE_special,
"setchapternewpage", CF_line | CF_global_unique, 1,
"setfilename", CF_line | CF_global_unique, LINE_text,
"settitle", CF_line | CF_global_unique, LINE_line,
"shortcaption", CF_brace, BRACE_context,
"shortcontents", CF_line | CF_global, LINE_skipline,
"shorttitlepage", CF_line | CF_global_unique, LINE_line,
"slanted", CF_brace, BRACE_style,
"smallbook", CF_line, LINE_skipline,
"smalldisplay", CF_block | CF_preformatted, 0,
"smallexample", CF_block | CF_preformatted | CF_preformatted_code, 0,
"smallformat", CF_block | CF_preformatted, 0,
"smallindentedblock", CF_block, 0,
"smalllisp", CF_block | CF_preformatted | CF_preformatted_code, 0,
"smallquotation", CF_block, 1,
"sortas", CF_brace, 1,
"sp", CF_line, 1,
"ss", CF_brace, 0,
"strong", CF_brace, BRACE_style,
"sub", CF_brace, BRACE_style,
"subentry", CF_line, LINE_line,
"subheading", CF_line | CF_sectioning, LINE_line,
"subsection", CF_root | CF_line | CF_sectioning, LINE_line,
"subsubheading", CF_line | CF_sectioning, LINE_line,
"subsubsection", CF_root | CF_line | CF_sectioning, LINE_line,
"subtitle", CF_line | CF_global, LINE_line,
"summarycontents", CF_line | CF_global, LINE_skipline,
"sup", CF_brace, BRACE_style,
"syncodeindex", CF_line, 2,
"synindex", CF_line, 2,
"t", CF_brace | CF_code_style, BRACE_other,
"tab", CF_other, OTHER_skipspace,
"table", CF_block | CF_blockitem, 1,
"tex", CF_block | CF_format_raw, 0,
"textdegree", CF_brace, 0,
"th", CF_brace, 0,
"thischapter", CF_other | CF_in_heading, OTHER_noarg,
"thischaptername", CF_other | CF_in_heading, OTHER_noarg,
"thischapternum", CF_other | CF_in_heading, OTHER_noarg,
"thisfile", CF_other | CF_in_heading, OTHER_noarg,
"thispage", CF_other | CF_in_heading, OTHER_noarg,
"thistitle", CF_other | CF_in_heading, OTHER_noarg,
"tie", CF_brace, 0,
"tieaccent", CF_brace | CF_accent, BRACE_accent,
"title", CF_line | CF_global_unique, LINE_line,
"titlefont", CF_brace | CF_global, 1,
"titlepage", CF_block | CF_global_unique, BLOCK_region,
"today", CF_brace, 0,
"top", CF_root | CF_line | CF_sectioning | CF_global_unique, LINE_line,
"u", CF_brace | CF_accent, BRACE_accent,
"ubaraccent", CF_brace | CF_accent, BRACE_accent,
"udotaccent", CF_brace | CF_accent, BRACE_accent,
"unmacro", CF_line, LINE_special,
"unnumbered", CF_root | CF_line | CF_sectioning, LINE_line,
"unnumberedsec", CF_root | CF_line | CF_sectioning, LINE_line,
"unnumberedsubsec", CF_root | CF_line | CF_sectioning, LINE_line,
"unnumberedsubsubsec", CF_root | CF_line | CF_sectioning, LINE_line,
"uref", CF_brace, 3,
"urefbreakstyle", CF_line | CF_global, 1,
"url", CF_brace, 3,
"v", CF_brace | CF_accent, BRACE_accent,
"value", CF_brace, 0,
"var", CF_brace, BRACE_style,
"verb", CF_brace | CF_code_style, BRACE_other,
"verbatim", CF_block, BLOCK_raw,
"verbatiminclude", CF_line, LINE_text,
"vskip", CF_line, LINE_lineraw,
"vtable", CF_block | CF_blockitem, 1,
"w", CF_brace, BRACE_other,
"xml", CF_block | CF_format_raw, 0,
"xref", CF_brace | CF_ref, 5,
"xrefautomaticsectiontitle", CF_line | CF_global, 1,
"{", CF_nobrace, 0,
"|", CF_nobrace, 0,
"}", CF_nobrace, 0,
"~", CF_brace | CF_accent, BRACE_accent,
};
